@@ -138,7 +138,7 @@ class File(BaseFile):
                 f'size={self.size!r}, '
                 f'format={self.format!r})')
 
-    def download(  # noqa: max-complexity=38
+    def download(  # noqa: C901,PLR0911,PLR0912,PLR0915
         self,
         file_path=None,
         verbose=None,
@@ -430,7 +430,7 @@ class File(BaseFile):
         :param verbose: (optional) Print actions to stdout.
 
         :type debug: bool
-        :param debug: (optional) Set to True to print headers to stdout and exit exit
+        :param debug: (optional) Set to True to print headers to stdout and exit
                       without sending the delete request.
 
         """
@@ -461,7 +461,7 @@ class File(BaseFile):
         else:
             if verbose:
                 msg = f' deleting: {self.name}'
-                if cascade_delete:
+                if cascade_delete == '1':
                     msg += ' and all derivative files.'
                 print(msg, file=sys.stderr)
             prepared_request = self.item.session.prepare_request(request)
